<?php
if (!defined('ABSPATH')) {
    exit;
}

class CBTT_Public {
    private $options;
    
    public function init() {
        $this->options = get_option('cbtt_options');
        
        add_action('wp_enqueue_scripts', array($this, 'enqueue_scripts'));
        add_action('wp_footer', array($this, 'add_back_to_top_button'));
    }
    
    public function enqueue_scripts() {
        wp_enqueue_style(
            'cbtt-styles',
            CBTT_PLUGIN_URL . 'assets/css/cbtt-styles.css',
            array(),
            CBTT_PLUGIN_VERSION
        );
        
        wp_enqueue_script(
            'cbtt-scripts',
            CBTT_PLUGIN_URL . 'assets/js/cbtt-scripts.js',
            array('jquery'),
            CBTT_PLUGIN_VERSION,
            true
        );
        
        wp_localize_script(
            'cbtt-scripts',
            'cbttOptions',
            $this->options
        );
    }
    
    public function add_back_to_top_button() {
        $position = isset($this->options['position']) ? $this->options['position'] : 'right';
        $button_color = isset($this->options['button_color']) ? $this->options['button_color'] : '#3498db';
        $arrow_color = isset($this->options['arrow_color']) ? $this->options['arrow_color'] : '#ffffff';
        $gauge_enabled = isset($this->options['gauge_enabled']) ? $this->options['gauge_enabled'] : 'yes';
        $gauge_color = isset($this->options['gauge_color']) ? $this->options['gauge_color'] : '#2ecc71';
        
        $position_class = 'cbtt-position-' . $position;
        $gauge_class = ($gauge_enabled === 'yes') ? 'cbtt-gauge-enabled' : 'cbtt-gauge-disabled';
        
        $inline_styles = '
            <style>
                .cbtt-back-to-top-button {
                    background-color: ' . esc_attr($button_color) . ';
                }
                .cbtt-back-to-top-arrow {
                    border-color: ' . esc_attr($arrow_color) . ';
                }
                .cbtt-progress-circle .cbtt-circle-path {
                    stroke: ' . esc_attr($gauge_color) . ';
                }
            </style>
        ';
        
        $button_html = '
            <div class="cbtt-back-to-top-container ' . esc_attr($position_class) . ' ' . esc_attr($gauge_class) . '">
                <div class="cbtt-back-to-top-button">
                    <span class="cbtt-back-to-top-arrow"></span>
                    <svg class="cbtt-progress-circle" width="100%" height="100%" viewBox="0 0 100 100">
                        <circle class="cbtt-circle-bg" cx="50" cy="50" r="45" />
                        <circle class="cbtt-circle-path" cx="50" cy="50" r="45" />
                    </svg>
                </div>
            </div>
        ';
        
        echo $inline_styles . $button_html;
    }
}
