<?php
if (!defined('ABSPATH')) {
    exit;
}

class CBTT_Settings {
    private $options;
    
    public function init() {
        $this->options = get_option('cbtt_options');
        
        add_action('admin_init', array($this, 'register_settings'));
        add_action('admin_menu', array($this, 'add_settings_page'));
        add_filter('plugin_action_links_' . plugin_basename(CBTT_PLUGIN_DIR . 'circular-back-to-top.php'), array($this, 'add_settings_link'));
    }
    
    public function register_settings() {
        register_setting(
            'cbtt_options_group',
            'cbtt_options',
            array($this, 'sanitize_options')
        );
        
        add_settings_section(
            'cbtt_general_section',
            'ボタン設定',
            array($this, 'general_section_callback'),
            'cbtt_settings'
        );
        
        add_settings_field(
            'position',
            'ボタン位置',
            array($this, 'position_callback'),
            'cbtt_settings',
            'cbtt_general_section'
        );
        
        add_settings_field(
            'button_color',
            'ボタンの色',
            array($this, 'button_color_callback'),
            'cbtt_settings',
            'cbtt_general_section'
        );
        
        add_settings_field(
            'arrow_color',
            '矢印の色',
            array($this, 'arrow_color_callback'),
            'cbtt_settings',
            'cbtt_general_section'
        );
        
        add_settings_field(
            'gauge_enabled',
            'インジケーター表示',
            array($this, 'gauge_enabled_callback'),
            'cbtt_settings',
            'cbtt_general_section'
        );
        
        add_settings_field(
            'gauge_color',
            'インジケーターの色',
            array($this, 'gauge_color_callback'),
            'cbtt_settings',
            'cbtt_general_section'
        );
    }
    
    public function sanitize_options($input) {
        $new_input = array();
        
        if (isset($input['position']))
            $new_input['position'] = sanitize_text_field($input['position']);
            
        if (isset($input['button_color']))
            $new_input['button_color'] = sanitize_hex_color($input['button_color']);
            
        if (isset($input['arrow_color']))
            $new_input['arrow_color'] = sanitize_hex_color($input['arrow_color']);
            
        if (isset($input['gauge_enabled']))
            $new_input['gauge_enabled'] = $input['gauge_enabled'];
            
        if (isset($input['gauge_color']))
            $new_input['gauge_color'] = sanitize_hex_color($input['gauge_color']);
            
        return $new_input;
    }
    
    public function add_settings_page() {
        add_options_page(
            'トップボタン設定',
            'トップボタン',
            'manage_options',
            'cbtt_settings',
            array($this, 'settings_page_content')
        );
    }
    
    public function add_settings_link($links) {
        $settings_link = '<a href="options-general.php?page=cbtt_settings">設定</a>';
        array_unshift($links, $settings_link);
        return $links;
    }
    
    public function general_section_callback() {
        echo '<p>トップへ戻るボタンのカラーと位置をカスタマイズします。</p>';
    }
    
    public function position_callback() {
        $position = isset($this->options['position']) ? $this->options['position'] : 'right';
        ?>
        <select name="cbtt_options[position]">
            <option value="left" <?php selected($position, 'left'); ?>>左下</option>
            <option value="center" <?php selected($position, 'center'); ?>>中央下</option>
            <option value="right" <?php selected($position, 'right'); ?>>右下</option>
        </select>
        <?php
    }
    
    public function button_color_callback() {
        $button_color = isset($this->options['button_color']) ? $this->options['button_color'] : '#3498db';
        ?>
        <input type="text" name="cbtt_options[button_color]" value="<?php echo esc_attr($button_color); ?>" class="cbtt-color-picker" data-default-color="#3498db" />
        <?php
    }
    
    public function arrow_color_callback() {
        $arrow_color = isset($this->options['arrow_color']) ? $this->options['arrow_color'] : '#ffffff';
        ?>
        <input type="text" name="cbtt_options[arrow_color]" value="<?php echo esc_attr($arrow_color); ?>" class="cbtt-color-picker" data-default-color="#ffffff" />
        <?php
    }
    
    public function gauge_enabled_callback() {
        $gauge_enabled = isset($this->options['gauge_enabled']) ? $this->options['gauge_enabled'] : 'yes';
        ?>
        <select name="cbtt_options[gauge_enabled]">
            <option value="yes" <?php selected($gauge_enabled, 'yes'); ?>>有効</option>
            <option value="no" <?php selected($gauge_enabled, 'no'); ?>>無効</option>
        </select>
        <?php
    }
    
    public function gauge_color_callback() {
        $gauge_color = isset($this->options['gauge_color']) ? $this->options['gauge_color'] : '#2ecc71';
        ?>
        <input type="text" name="cbtt_options[gauge_color]" value="<?php echo esc_attr($gauge_color); ?>" class="cbtt-color-picker" data-default-color="#2ecc71" />
        <?php
    }
    
    public function settings_page_content() {
        ?>
        <div class="wrap">
            <h1>トップボタン設定</h1>
            <form method="post" action="options.php">
                <?php
                settings_fields('cbtt_options_group');
                do_settings_sections('cbtt_settings');
                submit_button('設定を保存');
                ?>
            </form>
        </div>
        
        <script>
            jQuery(document).ready(function($) {
                $('.cbtt-color-picker').wpColorPicker();
            });
        </script>
        <?php
    }
}
